# area4 Support

Here are some support links that may help you out:

- [Library Documentation](https://area4.readthedocs.io/en/stable/)
- [Issues / Bug Tracker](https://github.com/area4lib/area4/issues)
- [Support Email](mailto:support@rdil.rocks)
